@@ -7,13 +7,16 @@ class XfBase:
   For extracting the common part to deal with transducer related logic.
   """
 
+  def _init_(self, xf):
+    self.xf = xf
+
   def init(self):
     return getAttribute(self.xf, '@@transducer/init')()
 
   def result(self, result):
     return getAttribute(self.xf, '@@transducer/result')(result)
 
-  def step(self, result, input):
+  def step(self, result, _input):
     raise Exception('Child class should implement this')
 
   def get(self, name, default=None):
